import { Component, ViewChild, ViewEncapsulation } from '@angular/core';
import { NavParams, Slides, ViewController } from 'ionic-angular';
// PROVIDERS
import { Loading } from '../providers/loading/loading';
var MultiLevelSelectDialogComponent = (function () {
    function MultiLevelSelectDialogComponent(loading, params, viewCtrl) {
        this.loading = loading;
        this.params = params;
        this.viewCtrl = viewCtrl;
        this.selectDialogTitle = 'Please Select';
        this.slides = null;
        this.selectedItemId = null;
        this.lookups = null;
    }
    MultiLevelSelectDialogComponent.prototype.ionViewDidLoad = function () {
        // Need to show a progress UI since it might take 1-2 secs to init the dialog if the lookups contains many items
        this.loading.present();
    };
    // checking if user is allowed to see this page. Runs when the page has fully entered and is now the active page. This event will fire, whether it was the first load or a cached page.
    // checking if user is allowed to see this page. Runs when the page has fully entered and is now the active page. This event will fire, whether it was the first load or a cached page.
    MultiLevelSelectDialogComponent.prototype.ionViewDidEnter = 
    // checking if user is allowed to see this page. Runs when the page has fully entered and is now the active page. This event will fire, whether it was the first load or a cached page.
    function () {
        var _selectedItemId = this.params.get('selectedItemId');
        this.selectedItemId = _selectedItemId;
        var lookups = this.params.get('lookups');
        if (lookups) {
            this.lookups = lookups;
        }
        else {
            this.loading.dismiss();
            throw new Error("MultiLevelSelectDialogComponent: lookups is missing; lookups: " + JSON.stringify(lookups));
        }
        var allowParent = this.params.get('allowParent');
        this.allowParent = allowParent;
        var _selectDialogTitle = this.params.get('selectDialogTitle');
        this.selectDialogTitle = _selectDialogTitle;
        this.slides = this.buildInitialSlide(this.lookups);
        this.slidesControl.lockSwipes(true);
        // dismiss the progress UI when the dialog UI is initialized
        this.loading.dismiss();
    };
    MultiLevelSelectDialogComponent.prototype.buildInitialSlide = function (lookUpsAsTree) {
        var _this = this;
        var slides = [];
        if (lookUpsAsTree && lookUpsAsTree.length > 0) {
            var currentSlideIndex = 0;
            var slideItemSelected_1 = false;
            var _topParentSlideItems_1 = [];
            var _topParentSlide_1 = { parentSlideItem: null, parentSlide: null, slideIndex: currentSlideIndex, items: _topParentSlideItems_1 };
            slides.push(_topParentSlide_1);
            lookUpsAsTree.forEach(function (lookUpItem, index) {
                var _parentSlideItem = {
                    id: lookUpItem.id, name: lookUpItem.name, parentId: null, lookUpItem: lookUpItem, slide: _topParentSlide_1, nextSlideIndex: lookUpItem.children.length > 0 ? undefined : null
                };
                if (!slideItemSelected_1 && _this.selectedItemId && (_parentSlideItem.id === _this.selectedItemId || _this.isThisLookUpItemHasAnyDescendantSelected(lookUpItem))) {
                    _parentSlideItem.selected = true;
                    slideItemSelected_1 = true;
                }
                _topParentSlideItems_1.push(_parentSlideItem);
            });
        }
        else {
            var _topParentSlideItems = [];
            var _topParentSlide = { parentSlideItem: null, parentSlide: null, slideIndex: 0, items: _topParentSlideItems };
            slides.push(_topParentSlide);
        }
        return slides;
    };
    MultiLevelSelectDialogComponent.prototype.addChildren = function (parentSlide, parentSlideItem, children) {
        var _this = this;
        var slides = [];
        var currentSlideIndex = this.slides.length;
        parentSlideItem.nextSlideIndex = currentSlideIndex;
        var slideItemSelected = false;
        var _slideItems = [];
        var _slide = { parentSlideItem: parentSlideItem, parentSlide: parentSlide, slideIndex: currentSlideIndex, items: _slideItems };
        slides.push(_slide);
        children.forEach(function (lookUpItem, index) {
            if (!lookUpItem.children) {
                lookUpItem.children = [];
            }
            var _slideItem = {
                id: lookUpItem.id, name: lookUpItem.name, parentId: lookUpItem.parentId, lookUpItem: lookUpItem, slide: _slide, nextSlideIndex: lookUpItem.children.length > 0 ? undefined : null
            };
            if (!slideItemSelected && _this.selectedItemId && (_slideItem.id === _this.selectedItemId || _this.isThisLookUpItemHasAnyDescendantSelected(lookUpItem))) {
                _slideItem.selected = true;
                slideItemSelected = true;
            }
            _slideItems.push(_slideItem);
        });
        var newSlides = this.slides.concat(slides);
        this.slides = newSlides;
    };
    MultiLevelSelectDialogComponent.prototype.isThisLookUpItemHasAnyDescendantSelected = function (lookUpItem) {
        if (this.selectedItemId) {
            var lookUpItemFound = this.getLookUpItemById(lookUpItem.children, this.selectedItemId);
            return lookUpItemFound != null;
        }
        else {
            return false;
        }
    };
    MultiLevelSelectDialogComponent.prototype.getLookUpItemById = function (lookUps, selectedItemId) {
        var lookUpItemFound = null;
        var recurse = function (_lookUps) {
            // tslint:disable-next-line:prefer-for-of
            for (var i = 0; i < _lookUps.length; i++) {
                // Found the lookUpItem!
                if ((_lookUps[i].id === selectedItemId)) {
                    lookUpItemFound = _lookUps[i];
                    break;
                    // Did not match...
                }
                else {
                    // Are there children / sub-categories? YES
                    if (_lookUps[i].children && _lookUps[i].children.length > 0) {
                        recurse(_lookUps[i].children);
                        if (lookUpItemFound) {
                            break;
                        }
                    }
                }
            }
        };
        recurse(lookUps);
        return lookUpItemFound;
    };
    MultiLevelSelectDialogComponent.prototype.close = function () {
        this.itemSelected(null);
    };
    MultiLevelSelectDialogComponent.prototype.handleItemClick = function (item) {
        if (item.nextSlideIndex === null) {
            this.itemSelected(item);
        }
        else {
            this.slideTo(item);
        }
    };
    MultiLevelSelectDialogComponent.prototype.itemSelected = function (item) {
        var selectedItem = null;
        if (item) {
            // selectedItem = { id: item.id, name: item.name };
            selectedItem = item.lookUpItem;
        }
        this.viewCtrl.dismiss(selectedItem);
    };
    MultiLevelSelectDialogComponent.prototype.slideTo = function (itemOrIndex) {
        var _this = this;
        if (itemOrIndex != null) {
            var nextSlideIndex_1 = null;
            if (itemOrIndex.id != null) {
                if (itemOrIndex.nextSlideIndex != null) {
                    nextSlideIndex_1 = itemOrIndex.nextSlideIndex;
                }
                else {
                    // below we check that nextSlideIndex is undefined
                    if (itemOrIndex.nextSlideIndex !== null) {
                        var item = itemOrIndex;
                        this.addChildren(item.slide, item, item.lookUpItem.children);
                        nextSlideIndex_1 = item.nextSlideIndex;
                    }
                    else {
                        throw new Error("MultiLevelSelectDialogComponent: itemOrIndex.nextSlideIndex must not be null; itemOrIndex: " + JSON.stringify(itemOrIndex));
                    }
                }
            }
            else {
                nextSlideIndex_1 = itemOrIndex;
            }
            setTimeout(function () {
                _this.slidesControl.lockSwipes(false);
                _this.slidesControl.slideTo(nextSlideIndex_1);
                _this.slidesControl.lockSwipes(true);
            }, 500);
        }
        else {
            throw new Error("MultiLevelSelectDialogComponent: itemOrIndex must not be null; itemOrIndex: " + JSON.stringify(itemOrIndex));
        }
    };
    MultiLevelSelectDialogComponent.decorators = [
        { type: Component, args: [{
                    selector: 'ryaa-multi-level-select-dialog',
                    template: "\n    <ion-content>\n      <ion-slides [pager]=\"false\">\n        <ion-slide *ngFor=\"let slide of slides\">\n          <ion-list-header>\n\n              <ion-toolbar>\n                <ion-buttons left>\n                  <button ion-button icon-only *ngIf=\"slide.parentSlide\" (click)=\"slideTo(slide.parentSlide?.slideIndex)\">\n                    <ion-icon name=\"arrow-back\"></ion-icon>\n                  </button>\n                </ion-buttons>\n                <ion-title>{{ slide.parentSlideItem ? slide.parentSlideItem?.name : selectDialogTitle }}</ion-title>\n                <ion-buttons right>\n                  <button ion-button icon-only (click)=\"close()\">\n                    <ion-icon name=\"close\"></ion-icon>\n                  </button>\n                </ion-buttons>\n              </ion-toolbar>\n\n          </ion-list-header>\n\n          <ion-list no-lines>\n\n            <ion-item class=\"parent-item\" *ngIf=\"slide.parentSlide && allowParent\" (click)=\"itemSelected(slide.parentSlideItem)\">\n              {{ slide.parentSlideItem?.name }}\n            </ion-item>\n\n            <ion-item  [ngClass]=\"{ 'selected': item.selected }\" *ngFor=\"let item of slide.items\" (click)=\"handleItemClick(item)\">\n              {{ item.name }}\n              <ion-icon  *ngIf=\"item.nextSlideIndex !== null\" item-right name=\"arrow-forward\"></ion-icon>\n            </ion-item>\n\n          </ion-list>\n        </ion-slide>\n      </ion-slides>\n    </ion-content>\n  ",
                    styles: ["\n    ryaa-multi-level-select-dialog ion-content ion-slides .slide-zoom {\n      height: 100%;\n    }\n    ryaa-multi-level-select-dialog ion-content ion-slides .slide-zoom ion-list-header {\n      margin-bottom: 1px;\n      padding-left: 0;\n      font-family: \"Roboto\", sans-serif;\n      background-color: #25A0DA;\n      border-color: #25A0DA;\n    }\n    ryaa-multi-level-select-dialog ion-content ion-slides .slide-zoom ion-list-header ion-label {\n      margin: 0;\n    }\n    ryaa-multi-level-select-dialog ion-content ion-slides .slide-zoom ion-list-header ion-label ion-toolbar .toolbar-background {\n      background-color: #25A0DA;\n    }\n    ryaa-multi-level-select-dialog ion-content ion-slides .slide-zoom ion-list-header ion-label ion-toolbar ion-buttons button {\n      color: #ffffff;\n    }\n    ryaa-multi-level-select-dialog ion-content ion-slides .slide-zoom ion-list-header ion-label ion-toolbar ion-title .toolbar-title {\n      font-size: 18px;\n      color: #ffffff;\n    }\n    ryaa-multi-level-select-dialog ion-content ion-slides .slide-zoom ion-list {\n      height: calc(100% - 59px);\n      overflow-y: scroll;\n    }\n    ryaa-multi-level-select-dialog ion-content ion-slides .slide-zoom ion-list ion-item ion-label {\n      margin-top: 10px;\n      margin-bottom: 10px;\n    }\n    ryaa-multi-level-select-dialog ion-content ion-slides .slide-zoom ion-list ion-item ion-icon {\n      font-size: 20px;\n      line-height: 30px;\n    }\n    ryaa-multi-level-select-dialog ion-content ion-slides .slide-zoom ion-list ion-item.selected {\n      background-color: #eee;\n    }\n    ryaa-multi-level-select-dialog ion-content ion-slides .slide-zoom ion-list ion-item.parent-item {\n      padding-left: 0px;\n    }\n    ryaa-multi-level-select-dialog ion-content ion-slides .slide-zoom ion-list ion-item.parent-item .item-inner {\n      padding-left: 16px;\n      border-bottom: 1px solid #dedede;\n    }",
                        "@media only screen and (device-width: 375px) and (device-height: 812px) and (-webkit-device-pixel-ratio: 3) {\n      ryaa-multi-level-select-dialog ion-content ion-slides ion-slide ion-list-header.list-header-ios {\n        padding-top: 25px;\n      }\n    }"
                    ],
                    encapsulation: ViewEncapsulation.None
                },] },
    ];
    /** @nocollapse */
    MultiLevelSelectDialogComponent.ctorParameters = function () { return [
        { type: Loading, },
        { type: NavParams, },
        { type: ViewController, },
    ]; };
    MultiLevelSelectDialogComponent.propDecorators = {
        "slidesControl": [{ type: ViewChild, args: [Slides,] },],
    };
    return MultiLevelSelectDialogComponent;
}());
export { MultiLevelSelectDialogComponent };
//# sourceMappingURL=multi-level-select-dialog.js.map