import { Component, Input, forwardRef, ViewEncapsulation } from '@angular/core';
import { ModalController, NavParams } from 'ionic-angular';
import { NG_VALUE_ACCESSOR } from '@angular/forms';
// COMPONENTS
import { MultiLevelSelectDialogComponent } from './multi-level-select-dialog';
var MultiLevelSelectComponent = (function () {
    function MultiLevelSelectComponent(modalCtrl, params) {
        this.modalCtrl = modalCtrl;
        this.params = params;
        this.propagateChange = function (_) { };
        this.selectedItem = null;
    }
    MultiLevelSelectComponent.prototype.writeValue = function (value) {
        this.selectedItem = value;
    };
    MultiLevelSelectComponent.prototype.registerOnChange = function (fn) {
        this.propagateChange = fn;
    };
    MultiLevelSelectComponent.prototype.registerOnTouched = function () { } // tslint:disable-line:no-empty
    ; // tslint:disable-line:no-empty
    // tslint:disable-line:no-empty
    MultiLevelSelectComponent.prototype.open = function () {
        var _this = this;
        var multiLevelSelectDialogComponent = this.modalCtrl.create(MultiLevelSelectDialogComponent, {
            selectedItemId: this.selectedItem ? this.selectedItem.id : null,
            lookups: this.lookups,
            allowParent: this.allowParent,
            selectDialogTitle: this.selectDialogTitle,
        });
        multiLevelSelectDialogComponent.onDidDismiss(function (selectedItem) {
            if (selectedItem) {
                _this.selectedItem = selectedItem;
                _this.propagateChange(_this.selectedItem);
            }
        });
        multiLevelSelectDialogComponent.present();
    };
    MultiLevelSelectComponent.prototype.reset = function ($event) {
        $event.stopPropagation();
        this.selectedItem = null;
        this.propagateChange(this.selectedItem);
    };
    MultiLevelSelectComponent.decorators = [
        { type: Component, args: [{
                    selector: 'ryaa-multi-level-select',
                    template: "\n    <ion-toolbar (click)=\"open()\">\n      <ion-title [ngClass]=\"{ 'multi-level-select-placeholder': !selectedItem }\">{{ selectedItem ? selectedItem?.name : selectPlaceholder }}</ion-title>\n      <ion-buttons right>\n        <button *ngIf=\"selectedItem\" ion-button icon-only (click)=\"reset($event)\">\n          <i class=\"fa fa-times\" aria-hidden=\"true\"></i>\n        </button>\n        <button ion-button icon-only>\n          <i class=\"fa fa-caret-down\" aria-hidden=\"true\"></i>\n        </button>\n      </ion-buttons>\n    </ion-toolbar>\n  ",
                    styles: ["\n    ryaa-multi-level-select ion-toolbar {\n      min-height: 34px;\n    }\n    ryaa-multi-level-select ion-toolbar .toolbar-background {\n      background: #fcfcfc;\n      border: 1px solid #f4f4f4;\n    }\n    ryaa-multi-level-select ion-toolbar ion-title.title-ios {\n      padding-left: 0px;\n      padding-right: 0px;\n    }\n    ryaa-multi-level-select ion-toolbar ion-title.multi-level-select-placeholder {\n      opacity: .33;\n    }\n    ryaa-multi-level-select ion-toolbar ion-title .toolbar-title {\n      font: 400 15px \"Roboto\", sans-serif;\n      color: #373B40;\n    }\n    ryaa-multi-level-select ion-toolbar ion-title .toolbar-title.toolbar-title-ios {\n      text-align: left;\n      padding-left: 8px;\n    }\n    ryaa-multi-level-select ion-toolbar ion-buttons button i.fa.fa-times {\n      color: #ff5a5a;\n    }\n    ryaa-multi-level-select ion-toolbar ion-buttons button i.fa.fa-caret-down {\n      color: #999;\n    }\n  "],
                    encapsulation: ViewEncapsulation.None,
                    providers: [
                        {
                            provide: NG_VALUE_ACCESSOR,
                            useExisting: forwardRef(function () { return MultiLevelSelectComponent; }),
                            // tslint:disable-line:no-forward-ref
                            multi: true
                        }
                    ]
                },] },
    ];
    /** @nocollapse */
    MultiLevelSelectComponent.ctorParameters = function () { return [
        { type: ModalController, },
        { type: NavParams, },
    ]; };
    MultiLevelSelectComponent.propDecorators = {
        "selectPlaceholder": [{ type: Input },],
        "selectDialogTitle": [{ type: Input },],
        "lookups": [{ type: Input },],
        "allowParent": [{ type: Input },],
    };
    return MultiLevelSelectComponent;
}());
export { MultiLevelSelectComponent };
//# sourceMappingURL=multi-level-select.js.map